import { set, unset, defineType, definePlugin } from 'sanity';
import { jsx, jsxs } from 'react/jsx-runtime';
import { useRef, useEffect } from 'react';
import styled, { css } from 'styled-components';
import DOMPurify from 'dompurify';
import { usePrefersDark, useTheme, ThemeProvider, studioTheme } from '@sanity/ui';
var __freeze$2 = Object.freeze;
var __defProp$2 = Object.defineProperty;
var __template$2 = (cooked, raw) => __freeze$2(__defProp$2(cooked, "raw", {
  value: __freeze$2(raw || cooked.slice())
}));
var _a$2, _b$1, _c$1, _d$1, _e$1;
const Container$1 = styled.div(_a$2 || (_a$2 = __template$2(["\n  --svg-bg-color: rgba(23, 23, 23, 0.05);\n\n  background-image: linear-gradient(45deg, var(--svg-bg-color) 25%, transparent 25%),\n    linear-gradient(-45deg, var(--svg-bg-color) 25%, transparent 25%),\n    linear-gradient(45deg, transparent 75%, var(--svg-bg-color) 75%),\n    linear-gradient(-45deg, transparent 75%, var(--svg-bg-color) 75%);\n  background-size: 20px 20px;\n  background-position:\n    0 0,\n    0 10px,\n    10px -10px,\n    -10px 0;\n  display: flex;\n  justify-content: center;\n  align-items: center;\n  min-height: 250px;\n  border: 1px solid var(--card-border-color);\n  border-radius: 1px;\n  position: relative;\n\n  &:focus-within {\n    box-shadow:\n      0 0 0 2px var(--card-bg-color),\n      0 0 0 4px var(--card-focus-ring-color);\n  }\n\n  &.dark {\n    --svg-bg-color: rgb(255, 255, 255, 0.1);\n  }\n\n  input[type='file'] {\n    opacity: 0;\n    z-index: -1;\n    position: absolute;\n  }\n\n  input[type='file']:focus + label {\n    outline: 2px solid;\n  }\n\n  * {\n    box-sizing: border-box;\n  }\n"])));
const SvgWrapper = styled.div(_b$1 || (_b$1 = __template$2(["\n  display: flex;\n  max-height: 320px;\n\n  > div {\n    display: flex;\n    align-items: center;\n    justify-content: center;\n  }\n\n  svg {\n    max-height: 80%;\n    max-width: 80%;\n    display: flex;\n    margin: auto;\n    width: 100%;\n    height: 100%;\n  }\n"])));
const ButtonStyle = css(_c$1 || (_c$1 = __template$2(["\n  border-radius: 0.1875rem;\n  font: inherit;\n  outline: none;\n  border: 0;\n  padding: 0.85rem 1.75rem;\n  margin: 0;\n  color: #fff;\n  cursor: pointer;\n  font-size: 1rem;\n  font-weight: 500;\n"])));
const AddButton = styled.label(_d$1 || (_d$1 = __template$2(["\n  ", ";\n  color: #fff;\n  background-color: #4285f4;\n\n  &:hover {\n    background-color: #3a6fc8;\n  }\n"])), ButtonStyle);
const RemoveButton = styled.button(_e$1 || (_e$1 = __template$2(["\n  ", ";\n  position: absolute;\n  top: 10px;\n  right: 10px;\n  color: #fff;\n  background-color: #db4437;\n\n  &:hover {\n    background-color: #b43b31;\n  }\n"])), ButtonStyle);
const InlineSvgInput = _ref => {
  let {
    id,
    value,
    schemaType,
    onChange,
    focused
  } = _ref;
  const inputRef = useRef(null);
  const prefersDark = usePrefersDark();
  const scheme = prefersDark ? "dark" : "light";
  const theme = useTheme();
  const isDarkMode = theme.sanity.color.dark;
  const handleChange = event => {
    var _a2, _b2;
    const file = (_b2 = (_a2 = event.target) == null ? void 0 : _a2.files) == null ? void 0 : _b2[0];
    if (!file) return;
    const reader = new FileReader();
    reader.onload = readerEvent => {
      if (!readerEvent.target) return;
      onChange(set(readerEvent.target.result));
    };
    reader.readAsText(file);
  };
  const focus = () => {
    if (!inputRef.current) return;
    inputRef.current.focus();
  };
  useEffect(() => {
    if (focused) focus();
  }, [focused]);
  const clickedRemoveSvg = () => {
    if (confirm("Are you sure you want to remove the SVG?")) {
      onChange(unset());
      if (inputRef.current) inputRef.current.value = "";
    }
    return false;
  };
  return /* @__PURE__ */jsx(Container$1, {
    className: isDarkMode ? "dark" : "light",
    children: /* @__PURE__ */jsxs(ThemeProvider, {
      scheme,
      theme: studioTheme,
      children: [/* @__PURE__ */jsx("input", {
        accept: ".svg",
        id,
        ref: inputRef,
        type: "file",
        placeholder: schemaType.placeholder,
        onChange: handleChange,
        name: "inline-svg"
      }), !value && /* @__PURE__ */jsx(AddButton, {
        htmlFor: id,
        children: "Upload SVG"
      }), value && /* @__PURE__ */jsxs(SvgWrapper, {
        children: [/* @__PURE__ */jsx("div", {
          dangerouslySetInnerHTML: {
            __html: DOMPurify.sanitize(value)
          }
        }), /* @__PURE__ */jsx(RemoveButton, {
          onClick: clickedRemoveSvg,
          children: "Remove SVG"
        })]
      })]
    })
  });
};
const inlineSvgType = defineType({
  name: "inlineSvg",
  title: "Inline SVG",
  type: "string",
  components: {
    input: InlineSvgInput
  }
});
var __freeze$1 = Object.freeze;
var __defProp$1 = Object.defineProperty;
var __template$1 = (cooked, raw) => __freeze$1(__defProp$1(cooked, "raw", {
  value: __freeze$1(raw || cooked.slice())
}));
var _a$1;
const InlineSvgPreview = styled.div(_a$1 || (_a$1 = __template$1(["\n  svg {\n    width: 100%;\n    height: 100%;\n  }\n"])));
const InlineSvgPreviewComponent = _ref2 => {
  let {
    value,
    className,
    style
  } = _ref2;
  if (!value) {
    return null;
  }
  return /* @__PURE__ */jsx(InlineSvgPreview, {
    dangerouslySetInnerHTML: {
      __html: DOMPurify.sanitize(value)
    },
    className,
    style
  });
};
var __freeze = Object.freeze;
var __defProp = Object.defineProperty;
var __template = (cooked, raw) => __freeze(__defProp(cooked, "raw", {
  value: __freeze(raw || cooked.slice())
}));
var _a, _b, _c, _d, _e, _f, _g;
const Container = styled.div(_a || (_a = __template(["\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n\n  * {\n    box-sizing: border-box;\n  }\n"])));
const IconStyle = css(_b || (_b = __template(["\n  width: 35px;\n  height: 35px;\n  margin-right: 8px;\n  flex-shrink: 0;\n"])));
const Icon = styled(InlineSvgPreviewComponent)(_c || (_c = __template(["\n  ", "\n"])), IconStyle);
const IconStub = styled.div(_d || (_d = __template(["\n  ", "\n"])), IconStyle);
const Title = styled.span(_e || (_e = __template(["\n  display: block;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n  overflow: hidden;\n  overflow: clip;\n  font-size: 1rem;\n  line-height: calc(21 / 16);\n  color: ", "};\n"])), _ref3 => {
  let {
    empty
  } = _ref3;
  return empty ? "#6e7683" : "inherit";
});
const Subtitle = styled.span(_f || (_f = __template(["\n  display: block;\n  white-space: nowrap;\n  text-overflow: ellipsis;\n  overflow: hidden;\n  overflow: clip;\n  font-size: 0.8125rem;\n  line-height: calc(17 / 13);\n  color: #6e7683;\n"])));
const TextContainer = styled.div(_g || (_g = __template(["\n  overflow: hidden;\n"])));
const InlineSvgPreviewItem = _ref4 => {
  let {
    icon,
    title,
    subtitle
  } = _ref4;
  if (title && typeof title !== "string" || subtitle && typeof subtitle !== "string") {
    return /* @__PURE__ */jsx(Container, {
      children: "`InlineSvgPreviewItem` supports only string values for `title` and `subtitle` props."
    });
  }
  return /* @__PURE__ */jsxs(Container, {
    children: [icon ? /* @__PURE__ */jsx(Icon, {
      value: icon
    }) : /* @__PURE__ */jsx(IconStub, {}), /* @__PURE__ */jsxs(TextContainer, {
      children: [title ? /* @__PURE__ */jsx(Title, {
        children: title
      }) : /* @__PURE__ */jsx(Title, {
        empty: true,
        children: "Untitled"
      }), subtitle && /* @__PURE__ */jsx(Subtitle, {
        children: subtitle
      })]
    })]
  });
};
const inlineSvgInput = definePlugin(function () {
  let config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return {
    name: "sanity-plugin-inline-svg-input",
    schema: {
      types: [inlineSvgType]
    }
  };
});
export { InlineSvgPreviewComponent, InlineSvgPreviewItem, inlineSvgInput };
//# sourceMappingURL=index.esm.js.map
